@@ -4,7 +4,7 @@ from neo.Blockchain import GetBlockchain
 from neo.VM.ScriptBuilder import ScriptBuilder
 from neo.VM.InteropService import InteropInterface
 from neo.Network.NodeLeader import NodeLeader
-from neo.Prompt.Utils import parse_param, get_asset_attachments, lookup_addr_str, get_owners_from_params
+from neo.Prompt.Utils import parse_param, get_asset_attachments, lookup_addr_str, get_owners_from_params, gather_param, get_parse_addresses
 
 from neo.Implementations.Blockchains.LevelDB.DBCollection import DBCollection
 from neo.Implementations.Blockchains.LevelDB.DBPrefix import DBPrefix
@@ -154,25 +154,35 @@ def TestInvokeContract(wallet, args, withdrawal_tx=None,
         params = args[1:] if len(args) > 1 else []
 
         params, neo_to_attach, gas_to_attach = get_asset_attachments(params)
+        params, parse_addresses = get_parse_addresses(params)
         params.reverse()
 
+        if '--i' in params:
+            params = []
+            for index, iarg in enumerate(contract.Code.ParameterList):
+                param, abort = gather_param(index, iarg)
+                if abort:
+                    return None, None, None, None
+                params.append(param)
+            params.reverse()
+
         sb = ScriptBuilder()
 
         for p in params:
 
             if parse_params:
-                item = parse_param(p, wallet)
+                item = parse_param(p, wallet, parse_addr=parse_addresses)
             else:
                 item = p
             if type(item) is list:
                 item.reverse()
                 listlength = len(item)
                 for listitem in item:
-                    subitem = parse_param(listitem, wallet)
+                    subitem = parse_param(listitem, wallet, parse_addr=parse_addresses)
                     if type(subitem) is list:
                         subitem.reverse()
                         for listitem2 in subitem:
-                            subsub = parse_param(listitem2, wallet)
+                            subsub = parse_param(listitem2, wallet, parse_addr=parse_addresses)
                             sb.push(subsub)
                         sb.push(len(subitem))
                         sb.Emit(PACK)
@@ -420,21 +430,33 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet,
         shash = contract_state.Code.ScriptHash()
 
         invoke_args, neo_to_attach, gas_to_attach = get_asset_attachments(invoke_args)
+        invoke_args, no_parse_addresses = get_parse_addresses(invoke_args)
+
         invoke_args.reverse()
 
+        if '--i' in invoke_args:
+            invoke_args = []
+            for index, iarg in enumerate(contract_state.Code.ParameterList):
+                param, abort = gather_param(index, iarg)
+                if abort:
+                    return None, [], 0, None
+                else:
+                    invoke_args.append(param)
+            invoke_args.reverse()
+
         sb = ScriptBuilder()
 
         for p in invoke_args:
-            item = parse_param(p, wallet)
+            item = parse_param(p, wallet, parse_addr=no_parse_addresses)
             if type(item) is list:
                 item.reverse()
                 listlength = len(item)
                 for listitem in item:
-                    subitem = parse_param(listitem, wallet)
+                    subitem = parse_param(listitem, wallet, parse_addr=no_parse_addresses)
                     if type(subitem) is list:
                         subitem.reverse()
                         for listitem2 in subitem:
-                            subsub = parse_param(listitem2, wallet)
+                            subsub = parse_param(listitem2, wallet, parse_addr=no_parse_addresses)
                             sb.push(subsub)
                         sb.push(len(subitem))
                         sb.Emit(PACK)
@@ -507,13 +529,10 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet,
             testMode=invocation_test_mode
         )
 
+        engine.invocation_args = invoke_args
         engine.LoadScript(itx.Script, False)
         engine.LoadDebugInfoForScriptHash(debug_map, shash.Data)
 
-        # call execute in its own blocking thread
-
-#        reactor.stop()
-
         i_success = engine.Execute()
 
         service.ExecutionCompleted(engine, i_success)
