@@ -1,13 +1,12 @@
 import hashlib
-import pdb
 import datetime
 
+from neo.VM.OpCode import *
 from logzero import logger
 from neo.VM.RandomAccessStack import RandomAccessStack
 from neo.VM.ExecutionContext import ExecutionContext
 from neo.VM import VMState
-from neo.VM.OpCode import *
-from neo.VM.InteropService import Array, Struct, StackItem, CollectionMixin, Map, Boolean
+from neo.VM.InteropService import Array, Struct, CollectionMixin, Map, Boolean
 from neocore.UInt160 import UInt160
 from neo.Settings import settings
 from neo.VM.VMFault import VMFault
@@ -15,7 +14,7 @@ from neo.Prompt.vm_debugger import VMDebugger
 from logging import DEBUG as LOGGING_LEVEL_DEBUG
 
 
-class ExecutionEngine():
+class ExecutionEngine:
     _Table = None
     _Service = None
 
@@ -110,17 +109,16 @@ class ExecutionEngine():
         self._AltStack = RandomAccessStack(name='Alt')
         self._ExecutedScriptHashes = []
         self.ops_processed = 0
+        self._debug_map = None
         self._is_write_log = settings.log_vm_instructions
 
     def AddBreakPoint(self, position):
         self.CurrentContext.Breakpoints.add(position)
 
-    def LoadDebugInfo(self, debug_map=None):
-        if debug_map:
+    def LoadDebugInfoForScriptHash(self, debug_map, script_hash):
+        if debug_map and script_hash:
             self._debug_map = debug_map
-            for b in self._debug_map['breakpoints']:
-                self.AddBreakPoint(b)
-#                print("breakpoint %s " % b)
+            self._debug_map['script_hash'] = script_hash
 
     def Dispose(self):
         while self._InvocationStack.Count > 0:
@@ -144,7 +142,6 @@ class ExecutionEngine():
         estack = self._EvaluationStack
         istack = self._InvocationStack
         astack = self._AltStack
-#        print("VM STATE %s " % self._VMState)
 
         if opcode > PUSH16 and opcode != RET and context.PushOnly:
             return self.VM_FAULT_and_report(VMFault.UNKNOWN1)
@@ -592,16 +589,28 @@ class ExecutionEngine():
 
                 pubkey = estack.Pop().GetByteArray()
                 sig = estack.Pop().GetByteArray()
-
+                container = self.ScriptContainer
+                if not container:
+                    logger.debug("Cannot check signature without container")
+                    estack.PushT(False)
+                    return
                 try:
+                    res = self.Crypto.VerifySignature(container.GetMessage(), sig, pubkey)
+                    estack.PushT(res)
+                except Exception as e:
+                    estack.PushT(False)
+                    logger.error("Could not checksig: %s " % e)
 
-                    res = self.Crypto.VerifySignature(self.ScriptContainer.GetMessage(), sig, pubkey)
+            elif opcode == VERIFY:
+                pubkey = estack.Pop().GetByteArray()
+                sig = estack.Pop().GetByteArray()
+                message = estack.Pop().GetByteArray()
+                try:
+                    res = self.Crypto.VerifySignature(message, sig, pubkey, unhex=False)
                     estack.PushT(res)
-
                 except Exception as e:
                     estack.PushT(False)
                     logger.error("Could not checksig: %s " % e)
-                return
 
             elif opcode == CHECKMULTISIG:
 
@@ -893,6 +902,10 @@ class ExecutionEngine():
     def LoadScript(self, script, push_only=False):
 
         context = ExecutionContext(self, script, push_only)
+
+        if self._debug_map and context.ScriptHash() == self._debug_map['script_hash']:
+            context.Breakpoints = set(self._debug_map['breakpoints'])
+
         self._InvocationStack.PushT(context)
 
         self._ExecutedScriptHashes.append(context.ScriptHash())
