@@ -10,16 +10,18 @@ import logging
 import sys
 from time import sleep
 from logzero import logger
-from prompt_toolkit import prompt
-from prompt_toolkit.contrib.completers import WordCompleter
+from prompt_toolkit.completion import WordCompleter
 from prompt_toolkit.history import FileHistory
-from prompt_toolkit.shortcuts import print_tokens
-from prompt_toolkit.styles import style_from_dict
-from prompt_toolkit.token import Token
+from prompt_toolkit.shortcuts import print_formatted_text, PromptSession
+from prompt_toolkit import prompt
+from prompt_toolkit.formatted_text import FormattedText
+from prompt_toolkit.styles import Style
+from prompt_toolkit import prompt
 from twisted.internet import reactor, task
 
 from neo import __version__
 from neo.Core.Blockchain import Blockchain
+from neo.SmartContract.ContractParameter import ContractParameter, ContractParameterType
 from neocore.Fixed8 import Fixed8
 from neo.IO.MemoryStream import StreamManager
 from neo.Wallets.utils import to_aes_key
@@ -82,6 +84,10 @@ class PromptFileHistory(FileHistory):
 
 
 class PromptInterface:
+
+    prompt_completer = None
+    history = None
+
     go_on = True
 
     _walletdb_loop = None
@@ -106,8 +112,8 @@ class PromptInterface:
                 'config debug {on/off}',
                 'config sc-events {on/off}',
                 'config maxpeers {num_peers}',
-                'build {path/to/file.py} (test {params} {returntype} {needs_storage} {needs_dynamic_invoke} {test_params})',
-                'load_run {path/to/file.avm} (test {params} {returntype} {needs_storage} {needs_dynamic_invoke} {test_params})',
+                'build {path/to/file.py} (test {params} {returntype} {needs_storage} {needs_dynamic_invoke} [{test_params} or --i]) --no-parse-addr (parse address strings to script hash bytearray)',
+                'load_run {path/to/file.avm} (test {params} {returntype} {needs_storage} {needs_dynamic_invoke} [{test_params} or --i]) --no-parse-addr (parse address strings to script hash bytearray)',
                 'import wif {wif}',
                 'import nep2 {nep2_encrypted_key}',
                 'import contract {path/to/file.avm} {params} {returntype} {needs_storage} {needs_dynamic_invoke}',
@@ -144,38 +150,40 @@ class PromptInterface:
                 'withdraw all # withdraw all holds available',
                 'send {assetId or name} {address} {amount} (--from-addr={addr})',
                 'sign {transaction in JSON format}',
-                'testinvoke {contract hash} {params} (--attach-neo={amount}, --attach-gas={amount}) (--from-addr={addr})',
+                'testinvoke {contract hash} [{params} or --i] (--attach-neo={amount}, --attach-gas={amount}) (--from-addr={addr}) --no-parse-addr (parse address strings to script hash bytearray)',
                 'debugstorage {on/off/reset}'
                 ]
 
-    history = None
-
     token_style = None
     start_height = None
     start_dt = None
 
     def __init__(self, history_filename=None):
         if history_filename:
-            self.history = PromptFileHistory(history_filename)
+            PromptInterface.history = PromptFileHistory(history_filename)
 
         self.input_parser = InputParser()
         self.start_height = Blockchain.Default().Height
         self.start_dt = datetime.datetime.utcnow()
 
-        self.token_style = style_from_dict({
-            Token.Command: preferences.token_style['Command'],
-            Token.Neo: preferences.token_style['Neo'],
-            Token.Default: preferences.token_style['Default'],
-            Token.Number: preferences.token_style['Number'],
+        self.token_style = Style.from_dict({
+            "command": preferences.token_style['Command'],
+            "neo": preferences.token_style['Neo'],
+            "default": preferences.token_style['Default'],
+            "number": preferences.token_style['Number'],
         })
 
     def get_bottom_toolbar(self, cli=None):
         out = []
         try:
-            out = [(Token.Command, '[%s] Progress: ' % settings.net_name),
-                   (Token.Number, str(Blockchain.Default().Height + 1)),
-                   (Token.Neo, '/'),
-                   (Token.Number, str(Blockchain.Default().HeaderHeight + 1))]
+            # Note: not sure if prompt-toolkit still supports foreground colors, couldn't get it to work
+            # out = [("class:command", '[%s] Progress: ' % settings.net_name),
+            #        ("class:number", str(Blockchain.Default().Height + 1)),
+            #        ("class:neo", '/'),
+            #        ("class:number", str(Blockchain.Default().HeaderHeight + 1))]
+            return "[%s] Progress: %s/%s" % (settings.net_name,
+                                             str(Blockchain.Default().Height + 1),
+                                             str(Blockchain.Default().HeaderHeight + 1))
         except Exception as e:
             pass
 
@@ -204,9 +212,9 @@ class PromptInterface:
 
         all_completions = standard_completions + self._known_things
 
-        completer = WordCompleter(all_completions)
+        PromptInterface.prompt_completer = WordCompleter(all_completions)
 
-        return completer
+        return PromptInterface.prompt_completer
 
     def quit(self):
         print('Shutting down. This may take a bit...')
@@ -217,8 +225,8 @@ class PromptInterface:
     def help(self):
         tokens = []
         for c in self.commands:
-            tokens.append((Token.Command, "%s\n" % c))
-        print_tokens(tokens, self.token_style)
+            tokens.append(("class:command", "%s\n" % c))
+        print_formatted_text(FormattedText(tokens), style=self.token_style)
 
     def do_open(self, arguments):
         if self.Wallet:
@@ -605,15 +613,15 @@ class PromptInterface:
         out += "Time elapsed %s mins\n" % mins
         out += "Blocks per min %s \n" % bpm
         out += "TPS: %s \n" % tps
-        tokens = [(Token.Number, out)]
-        print_tokens(tokens, self.token_style)
+        tokens = [("class:number", out)]
+        print_formatted_text(FormattedText(tokens), style=self.token_style)
 
     def show_nodes(self):
         if len(NodeLeader.Instance().Peers) > 0:
             out = "Total Connected: %s\n" % len(NodeLeader.Instance().Peers)
             for peer in NodeLeader.Instance().Peers:
                 out += "Peer %s - IO: %s\n" % (peer.Name(), peer.IOStats())
-            print_tokens([(Token.Number, out)], self.token_style)
+            print_formatted_text(FormattedText([("class:number", out)]), style=self.token_style)
         else:
             print("Not connected yet\n")
 
@@ -626,8 +634,8 @@ class PromptInterface:
             if block is not None:
 
                 bjson = json.dumps(block.ToJson(), indent=4)
-                tokens = [(Token.Number, bjson)]
-                print_tokens(tokens, self.token_style)
+                tokens = [("class:number", bjson)]
+                print_formatted_text(FormattedText(tokens), style=self.token_style)
                 print('\n')
                 if txarg and 'tx' in txarg:
 
@@ -660,8 +668,8 @@ class PromptInterface:
                     jsn['height'] = height
                     jsn['unspents'] = [uns.ToJson(tx.outputs.index(uns)) for uns in
                                        Blockchain.Default().GetAllUnspent(txid)]
-                    tokens = [(Token.Command, json.dumps(jsn, indent=4))]
-                    print_tokens(tokens, self.token_style)
+                    tokens = [("class:command", json.dumps(jsn, indent=4))]
+                    print_formatted_text(FormattedText(tokens), style=self.token_style)
                     print('\n')
             except Exception as e:
                 print("Could not find transaction from args: %s (%s)" % (e, args))
@@ -676,8 +684,8 @@ class PromptInterface:
 
             if account is not None:
                 bjson = json.dumps(account.ToJson(), indent=4)
-                tokens = [(Token.Number, bjson)]
-                print_tokens(tokens, self.token_style)
+                tokens = [("class:number", bjson)]
+                print_formatted_text(FormattedText(tokens), style=self.token_style)
                 print('\n')
             else:
                 print("Account %s not found" % item)
@@ -695,8 +703,8 @@ class PromptInterface:
                 print("Found %s results for %s" % (len(results), query))
                 for asset in results:
                     bjson = json.dumps(asset.ToJson(), indent=4)
-                    tokens = [(Token.Number, bjson)]
-                    print_tokens(tokens, self.token_style)
+                    tokens = [("class:number", bjson)]
+                    print_formatted_text(FormattedText(tokens), style=self.token_style)
                     print('\n')
 
                 return
@@ -705,8 +713,8 @@ class PromptInterface:
 
             if asset is not None:
                 bjson = json.dumps(asset.ToJson(), indent=4)
-                tokens = [(Token.Number, bjson)]
-                print_tokens(tokens, self.token_style)
+                tokens = [("class:number", bjson)]
+                print_formatted_text(FormattedText(tokens), style=self.token_style)
                 print('\n')
             else:
                 print("Asset %s not found" % item)
@@ -729,8 +737,8 @@ class PromptInterface:
                     print("Found %s results for %s" % (len(contracts), query))
                     for contract in contracts:
                         bjson = json.dumps(contract.ToJson(), indent=4)
-                        tokens = [(Token.Number, bjson)]
-                        print_tokens(tokens, self.token_style)
+                        tokens = [("class:number", bjson)]
+                        print_formatted_text(FormattedText(tokens), style=self.token_style)
                         print('\n')
                 else:
                     print("Please specify a search query")
@@ -741,8 +749,8 @@ class PromptInterface:
                     contract.DetermineIsNEP5()
                     jsn = contract.ToJson()
                     bjson = json.dumps(jsn, indent=4)
-                    tokens = [(Token.Number, bjson)]
-                    print_tokens(tokens, self.token_style)
+                    tokens = [("class:number", bjson)]
+                    print_formatted_text(FormattedText(tokens), style=self.token_style)
                     print('\n')
         else:
             print("Please specify a contract")
@@ -758,11 +766,14 @@ class PromptInterface:
             tx, fee, results, num_ops = TestInvokeContract(self.Wallet, args, from_addr=from_addr, invoke_attrs=invoke_attrs, owners=owners)
 
             if tx is not None and results is not None:
+
+                parameterized_results = [ContractParameter.ToParameter(item) for item in results]
+
                 print(
                     "\n-------------------------------------------------------------------------------------------------------------------------------------")
                 print("Test invoke successful")
                 print("Total operations: %s" % num_ops)
-                print("Results %s" % [str(item) for item in results])
+                print("Results %s" % [item.ToJson() for item in parameterized_results])
                 print("Invoke TX GAS cost: %s" % (tx.Gas.value / Fixed8.D))
                 print("Invoke TX fee: %s" % (fee.value / Fixed8.D))
                 print(
@@ -794,7 +805,7 @@ class PromptInterface:
 
         if function_code:
 
-            contract_script = GatherContractDetails(function_code, self)
+            contract_script = GatherContractDetails(function_code)
 
             if contract_script is not None:
 
@@ -831,7 +842,7 @@ class PromptInterface:
         totalmb = total / (1024 * 1024)
         out = "Total: %s MB\n" % totalmb
         out += "Total buffers: %s\n" % StreamManager.TotalBuffers()
-        print_tokens([(Token.Number, out)], self.token_style)
+        print_formatted_text(FormattedText([("class:number", out)]), style=self.token_style)
 
     def handle_debug_storage(self, args):
         what = get_arg(args)
@@ -911,24 +922,24 @@ class PromptInterface:
         dbloop = task.LoopingCall(Blockchain.Default().PersistBlocks)
         dbloop.start(.1)
 
-#        Blockchain.Default().PersistBlocks()
+        tokens = [("class:neo", 'NEO'), ("class:default", ' cli. Type '),
+                  ("class:command", '\'help\' '), ("class:default", 'to get started')]
 
-        tokens = [(Token.Neo, 'NEO'), (Token.Default, ' cli. Type '),
-                  (Token.Command, '\'help\' '), (Token.Default, 'to get started')]
-
-        print_tokens(tokens, self.token_style)
+        print_formatted_text(FormattedText(tokens), style=self.token_style)
         print('\n')
 
         while self.go_on:
 
+            session = PromptSession("neo> ",
+                                    completer=self.get_completer(),
+                                    history=self.history,
+                                    bottom_toolbar=self.get_bottom_toolbar,
+                                    style=self.token_style,
+                                    refresh_interval=3,
+                                    )
+
             try:
-                result = prompt("neo> ",
-                                completer=self.get_completer(),
-                                history=self.history,
-                                get_bottom_toolbar_tokens=self.get_bottom_toolbar,
-                                style=self.token_style,
-                                refresh_interval=3
-                                )
+                result = session.prompt()
             except EOFError:
                 # Control-D pressed: quit
                 return self.quit()
